in_time_error = {
    "0:ERROR1": "Username and/or Secret-Key is missing in request",
    "0:ERROR2": "Bad Request",
    "0:ERROR3": "User is not verified",
    "1:ERROR1": "Data validation failure",
    "1:ERROR2": "Send date is past from current date and time",
    "1:ERROR3": "Recipients is incorrect",
    "2:ERROR0": "Loading the user's block list failed",
    "2:ERROR1": "Unable to send message",
    "2:ERROR2": "There is no recipient to send the message to"
}
